@@ -27,6 +27,7 @@ import logging
 import random
 import copy
 import serial.tools.list_ports
+import Queue
 
 class DeviceManager(object):
     """The DeviceManager manages devices.
@@ -34,6 +35,10 @@ class DeviceManager(object):
     It provides methods to add or delete devices,
     get their most recent measurement values and various other things.
 
+    .. attribute:: queue
+        The queue queues all incoming values.
+        They are stored in the format (deviceID, value)
+
     """
 
     _running = False
@@ -41,17 +46,19 @@ class DeviceManager(object):
     _thread = None
 
     _iterator = None
+    
+    queue = None
 
     devices = {}
     configs = {}
-    rawValues = {}
 
     def __init__(self):
         self._iterator = self._getIterator()
         self._start()
+        self.queue = Queue.Queue()
 
     def _getIterator(self):
-        i = random.getrandbits(32)
+        i = 1
         while True:
             yield i
             i += 1
@@ -69,12 +76,6 @@ class DeviceManager(object):
 
         return decoratedFunction
 
-    def _updateRawValues(self):
-        if self._running:
-            self.rawValues = self._thread.rawValues
-        else:
-            logging.warn("GetValuesThread not running. Can't update values.\n")
-
     def _getLinearFunction(self, value1, value2):
         """Return a linear function, which contains value1 and value2.
 
@@ -150,7 +151,8 @@ class DeviceManager(object):
 
         return tuple(portsList)
 
-    def getStatus(self):
+    @property
+    def status(self):
         """Returns the status of the deviceManager.
         
         True if deviceManager is running, otherwise False.
@@ -283,36 +285,15 @@ class DeviceManager(object):
             if len(config["subDevices"]) == 0 and config["deviceName"] == "XLS200":
                 self.closeDevice(i)
 
-    def getLastRawValue(self, deviceID):
-        """Returns the last raw value of device with ID deviceID.
-
-        If there is no last value (last value == None), it returns a NullValue.
-
-        :param deviceID: deviceID (e.g. XLS200, TecpelDMM8061 etc.)
-        :type deviceID: DeviceID
-        :returns: Last Value object of device with deviceID
-        :rtype: Value
+    def calibrate(self, rv, calibration, unit=""):
+        """Return a calibrated version of the value.
         
-        """
-
-        self._updateRawValues()
-
-        try:
-            return self.rawValues[deviceID]
-
-        except KeyError:
-            logging.info("No value yet. Device: %s %s", deviceID, self.getDevice(deviceID))
-            return devicesModule.NullValue()
-
-    def getCalibratedLastRawValue(self, deviceID, calibration, unit=None):
-        """Return a calibrated value from the getLastRawValue method.
-        
-        :param deviceID: DeviceID
-        :type deviceID: DeviceID
+        :param rv: Value to be calibrated
+        :type rv: Value
         :param calibration: Calibration tuple
         :type calibration: Tuple
-        :param unit: Unit or None
-        :type unit: String or None
+        :param unit: Unit
+        :type unit: String
 
         The calibration tuple must contain either two integers m, c
         to create a function of style f(x) = m x + c
@@ -335,9 +316,6 @@ class DeviceManager(object):
             def factor(self):
                 return si.getFactor(self.prefix)
 
-        rv = self.getLastRawValue(deviceID)
-        if rv == None: return None
-
         result = __Value()
 
         result.value, result.prefix = si.getNumberPrefix(linearFunction(rv.completeValue))
@@ -371,8 +349,8 @@ class DeviceManager(object):
 
         if self._running == False:
             self._stopEvent = threading.Event()
-            self._thread = _GetValuesThread(self._stopEvent,
-                self.devices, self.configs)
+            self._thread = GetValuesThread(self._stopEvent,
+                self.devices, self.configs, self.queue)
             self._thread.start()
             self._running = True
 
@@ -387,12 +365,8 @@ class DeviceManager(object):
             self._running = False
 
 
-class _GetValuesThread(threading.Thread):
-    devices = {}
-    configs = {}
-    rawValues = {}
-
-    def __init__(self, stop_event, devices, configs):
+class GetValuesThread(threading.Thread):
+    def __init__(self, stop_event, devices, configs, queue):
         threading.Thread.__init__(self)
         self.daemon = True
         self.stop_event = stop_event
@@ -400,14 +374,12 @@ class _GetValuesThread(threading.Thread):
         self.devices = devices
         self.configs = configs
 
-        for key, val in self.devices.iteritems():
-            if key not in self.rawValues:
-                self.rawValues[key] = devicesModule.NullValue()
+        self.queue = queue
 
     def run(self):
-        while not self.stop_event.is_set():
-            self.updateValue()
-            time.sleep(0.2) # Prevent 100% CPU usage
+        if len(self.devices):
+            while not self.stop_event.is_set():
+                self.updateValue()
 
     def updateValue(self):
         # python3 incompatibility: iteritems
@@ -417,14 +389,20 @@ class _GetValuesThread(threading.Thread):
 
             try:
                 if isinstance(config["parent"], str):
+                    # If the parent of the device is a string (e.g. "COM1" or 
+                    # "/dev/ttyUSB0") then its a normal device -> So just gather
+                    # the value.
                     rv = self.devices[deviceID].getRawValue()
                     if rv:
-                        self.rawValues[deviceID] = rv
+                        self.queue.put((deviceID,rv))
 
                 else:
+                    # If the parent of the device is not a string but a deviceID
+                    # then its a subdevice -> So we need to ask the parent device
+                    # for the value.
                     rv = self.devices[config["parent"]].getRawValue(config["inputNumber"])
                     if rv:
-                        self.rawValues[deviceID] = rv
+                        self.queue.put((deviceID,rv))
 
             except serial.serialutil.SerialException as e:
                 logging.critical("Caught serial exception: " + str(e))
\ No newline at end of file
